/* This file was generated by syncqt. */
#ifndef QT_QTGRAPHS_VERSION_H
#define QT_QTGRAPHS_VERSION_H

#define QTGRAPHS_VERSION_STR "6.11.2"

#define QTGRAPHS_VERSION 0x0601102

#endif // QT_QTGRAPHS_VERSION_H
